@@ -27,7 +27,7 @@
 #include <QStyleOption>
 #include <QPainter>
 #include <QPaintEvent>
-#include <QTextEdit>
+#include <QTextBrowser>
 #include <QApplication>
 //#include <QMaemo5KineticScroller>
 #include <QHBoxLayout>
@@ -98,7 +98,7 @@ Widget::Widget(QWidget *parent) : QProgressBar (parent)
 	_maemo5Style = new QMaemo5Style;
 
 	// detailed info window objects
-	battInfo = new QTextEdit;
+	battInfo = new QTextBrowser;
 	//QMaemo5KineticScroller* ks = new QMaemo5KineticScroller(battInfo);
 	battInfo->setAttribute(Qt::WA_DeleteOnClose);
 	aboutAct = new QAction(tr("&ABOUT"), this);
